:github_url: https://github.com/stephane-caron/pink/tree/master/doc/src/index.rst

.. title:: Table of Contents

####
Pink
####

**P**\ ython **in**\ verse **k**\ inematics, a task-based whole-body inverse kinematics for your robot model based on `Pinocchio <https://github.com/stack-of-tasks/pinocchio>`_.

.. toctree::
    :maxdepth: 1

    installation.rst
    introduction.rst
    inverse-kinematics.rst
    tasks.rst
    extras.rst
    developer-notes.rst

You can also download this documentation as a `PDF document <pink.pdf>`_.
